/* ###
 * IP: GHIDRA
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package ghidra.trace.database.symbol;

import ghidra.program.model.address.Address;
import ghidra.trace.database.symbol.DBTraceReferenceSpace.DBTraceReferenceEntry;
import ghidra.trace.model.symbol.TraceOffsetReference;

public class DBTraceOffsetReference extends DBTraceReference implements TraceOffsetReference {

	private boolean isExternalBlockReference;

	public DBTraceOffsetReference(DBTraceReferenceEntry ent, boolean isExternalBlockReference) {
		super(ent);
		this.isExternalBlockReference = isExternalBlockReference;
	}

	@Override
	public long getOffset() {
		return ent.ext;
	}

	@Override
	public Address getBaseAddress() {
		if (isExternalBlockReference) {
			return ent.toAddress;
		}
		return ent.toAddress.subtractWrap(ent.ext);
	}
}
