/* ###
 * IP: GHIDRA
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package ghidra.pcodeCPort.slghpatexpress;

import java.io.PrintStream;

import generic.stl.VectorSTL;
import ghidra.pcodeCPort.utils.MutableInt;
import ghidra.sleigh.grammar.Location;

public class PlusExpression extends BinaryExpression {

	public PlusExpression(Location location) {
		super(location);
	}	// For use by restoreXml

	public PlusExpression(Location location, PatternExpression l, PatternExpression r) {
		super(location, l, r);
	}

	@Override
	public long getSubValue(VectorSTL<Long> replace, MutableInt listpos) {
		long leftval = getLeft().getSubValue(replace, listpos); // Must be left first
		long rightval = getRight().getSubValue(replace, listpos);
		return leftval + rightval;
	}

	@Override
	public void saveXml(PrintStream s) {
		s.append("<plus_exp>\n");
		super.saveXml(s);
		s.append("</plus_exp>\n");
	}

}
